@@ -1,13 +1,8 @@
 package Debian::ExtRepo::Commands::Disable;
 
-use v5.28;
-use warnings;
-
 use Dpkg::Control::HashCore;
 
 sub run {
-	my $config = shift;
-	my $mirror = shift;
 	my $repo = shift;
 	
 	my $aptfile = "/etc/apt/sources.list.d/extrepo_$repo.sources";
